@@ -131,7 +131,7 @@ When an error happens, a message is printed about the error.
 __author__ = "Nilton Volpato"
 __author_email__ = "nilton dot volpato | gmail com"
 __date__ = "2008-03-26"
-__version__ = "0.1a"
+__version__ = "0.1.1a"
 
 # TODO:
 #   - add support for short options to the parser
@@ -139,12 +139,13 @@ __version__ = "0.1a"
 # Changelog:
 #
 # 2008-03-26: v0.1a first public version
+# 2008-05-23: v0.1.1a removed external dependency of odict
 
 import inspect
 import os
 import sys
 import textwrap
-from nv.third_party.odict import odict
+from odict import odict
 
 
 def annotation(**ann):
